@@ -9,7 +9,8 @@ test in_main => sub {
     pass( "main" );
 };
 
-run_tests;
+run_me;
+done_testing;
 
 #
 # This file is part of Test-Roo
