@@ -9,7 +9,8 @@ test second_test => sub {
     pass( "second" );
 };
 
-run_tests;
+run_me;
+done_testing;
 
 #
 # This file is part of Test-Roo
